
# Slot: equals_string_in


the slot must have range string and the value of the slot must equal one of the specified values

URI: [linkml:equals_string_in](https://w3id.org/linkml/equals_string_in)


## Domain and Range

None &#8594;  <sub>0..\*</sub> [String](types/String.md)

## Parents

 *  is_a: [list_value_specification_constant](list_value_specification_constant.md)

## Children


## Used by

 * [AnonymousSlotExpression](AnonymousSlotExpression.md)
 * [AnonymousTypeExpression](AnonymousTypeExpression.md)
 * [SlotDefinition](SlotDefinition.md)
 * [SlotExpression](SlotExpression.md)
 * [TypeDefinition](TypeDefinition.md)
 * [TypeExpression](TypeExpression.md)
